"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const mongodb_1 = require("mongodb");
const crypto_1 = require("crypto");
/**
 * Constructs an ObjectId instance based on entity name.
 * Helpful for database references between two collections.
 *
 * @param name Entity name
 */
exports.getObjectId = (name) => {
    if (name === '') {
        throw new Error('Name cannot be empty');
    }
    const hash = crypto_1.createHash('sha1')
        .update(name, 'utf8')
        .digest('hex');
    return new mongodb_1.ObjectId(hash.substring(0, 24));
};
/**
 * Constructs ObjectId instances based on entity names.
 * Helpful for database references between two collections.
 *
 * @param names Array of object names
 */
exports.getObjectIds = (names) => {
    return names.map(name => exports.getObjectId(name));
};
//# sourceMappingURL=index.js.map